<?php /** @var ShipX_Shipment_Model $shipment */

use InspireLabs\WooInpost\EasyPack;
use InspireLabs\WooInpost\shipx\models\shipment\ShipX_Shipment_Model;
use InspireLabs\WooInpost\shipx\models\shipment\ShipX_Shipment_Parcel_Model; ?>
<?php /** @var string $wp_ajax_action_create */ ?>

<?php
if (!defined('ABSPATH')) {
    exit;
} ?>

<?php
$status_service = EasyPack()->get_shipment_status_service();
?>

<?php if (true === $wrong_api_env): ?>
    <?php
    $internal_data = $shipment->getInternalData();
    $origin_api = $shipment->getInternalData()->getApiVersion();
    if ($internal_data->getApiVersion()
        === $internal_data::API_VERSION_PRODUCTION
    ):?>

    <?php endif; ?>

    <?php if ($internal_data->getApiVersion()
        === $internal_data::API_VERSION_PRODUCTION
    ): ?>
        <span style="font-weight: bold; color: #a00">
            <?php _e('This shipment was created in production API. Change API environment to production to process this shipment',
                EasyPack::$text_domain) ?>
        </span>

    <?php endif; ?>

    <?php if ($internal_data->getApiVersion()
        === $internal_data::API_VERSION_SANDBOX
    ): ?>
        <span style="font-weight: bold; color: #a00">
            <?php _e('This shipment was created in sandbox API. Change API environment to sandbox to process this shipment',
                EasyPack::$text_domain) ?>
        </span>
    <?php endif; ?>
    <?php return; ?>
<?php endif; ?>

<?php $first_parcel = true;
$shipment_service = EasyPack()->get_shipment_service();
?>

<?php
$class = ['wc-enhanced-select'];
$custom_attributes = ['style' => 'width:100%;'];
if ($disabled) {
    $custom_attributes['disabled'] = 'disabled';
    $class[] = 'easypack-disabled';
}

?>

<p>
    <span style="font-weight: bold"><?php _e('Service:',
            EasyPack::$text_domain) ?>
    </span>
    <span>
        <?php echo $selected_service;
        ?>
    </span>
</p>

<p><span style="font-weight: bold"><?php _e('Status:',
            EasyPack::$text_domain) ?> </span>
    <?php if ($shipment instanceof ShipX_Shipment_Model): ?>
    <?php $status = $shipment->getInternalData()->getStatus() ?>
    <?php $status_title = $shipment->getInternalData()->getStatusTitle() ?>
    <?php $status_desc = $shipment->getInternalData()->getStatusDescription() ?>
    <span title="<?php echo $status_desc ?>"><?php echo $status_title ?>
        (<?php echo $status ?>)</span></p>
<?php if ($shipment->isCourier()) {
    $send_method = 'courier';
}

if ($shipment->isParcelMachine()) {
    $send_method = 'parcel_machine';
}
?>
<?php else: ?>
    <?php _e('Not created yet (new)', EasyPack::$text_domain) ?>
<?php endif ?>

<?php if (!empty($shipment instanceof ShipX_Shipment_Model
    && $shipment->getInternalData()->getTrackingNumber())
): ?>
    <span style="font-weight: bold">
            <?php _e('Tracking number:', EasyPack::$text_domain) ?>
    </span>

    <a target="_blank"
       href="<?php echo $shipment_service->getTrackingUrl($shipment) ?>">
        <?php echo $shipment->getInternalData()->getTrackingNumber() ?>
    </a>
    <div class="padding-bottom15"></div>
<?php endif ?>

<?php include('costs/html-order-metabox-costs.php'); ?>

<p><?php _e('Attributes:', EasyPack::$text_domain); ?>
<ol id="easypack_parcels" style="list-style: none">
    <?php /** @var ShipX_Shipment_Parcel_Model $parcel */ ?>
    <?php /** @var ShipX_Shipment_Parcel_Model[] $parcels */ ?>

    <?php foreach ($parcels as $parcel) : ?>
        <li>
            <?php if ($status == 'new') : ?>
                <?php
                $length = [
                    'type' => 'number',
                    'class' => ['easypack_parcel'],
                    'input_class' => ['easypack_parcel'],
                    'label' => __('Length:', EasyPack::$text_domain)
                    . ' (' . $parcel->getDimensions()->getUnit() . ')',
                    'required' => true,
                ];
                $width = [
                    'type' => 'number',
                    'class' => ['easypack_parcel'],
                    'input_class' => ['easypack_parcel'],
                    'label' => __('Width:', EasyPack::$text_domain)
                        . ' (' . $parcel->getDimensions()->getUnit() . ')',
                    'required' => true,
                ];
                $height = [
                    'type' => 'number',
                    'class' => ['easypack_parcel'],
                    'input_class' => ['easypack_parcel'],
                    'label' => __('Height:', EasyPack::$text_domain)
                        . ' (' . $parcel->getDimensions()->getUnit() . ')',
                    'required' => true,
                ];
                woocommerce_form_field('parcel_length', $length,
                    $parcel->getDimensions()->getLength());
                woocommerce_form_field('parcel_width', $width,
                    $parcel->getDimensions()->getWidth());
                woocommerce_form_field('parcel_height', $height,
                    $parcel->getDimensions()->getHeight());


                ?>

                <?php
                $weight = [
                    'type' => 'number',
                    'class' => ['easypack_parcel'],
                    'input_class' => ['easypack_parcel'],
                    'label' => __('Weight:', EasyPack::$text_domain)
                        . ' ' . $parcel->getWeight()->getUnit(),
                    'required' => true,
                ];
                woocommerce_form_field('parcel_weight', $weight,
                    $parcel->getWeight()->getAmount());

                ?>

                <?php
                $non_standard = [
                    'type' => 'select',
                    'options' => [
                        'no' => __('no', EasyPack::$text_domain),
                        'yes' => __('yes', EasyPack::$text_domain),

                    ],
                    'class' => ['easypack_parcel'],
                    'input_class' => ['easypack_parcel'],
                    'label' => __('Non standard', EasyPack::$text_domain),
                    'required' => true,
                ];
                woocommerce_form_field('parcel_non_standard', $non_standard,
                    $parcel->getTemplate());
                ?>

                <?php if ($status == 'new' && !$first_parcel) : ?>
                    <button class="button easypack_remove_parcel"><?php _e('Remove',
                            EasyPack::$text_domain); ?></button>
                <?php endif; ?>

            <?php else : ?>
                <?php _e('Lenght',
                    EasyPack::$text_domain); ?>: <?php echo $parcel
                    ->getDimensions()->getLength(); ?><?php echo $parcel
                    ->getDimensions()->getUnit(); ?>
                <br>
                <?php _e('Width',
                    EasyPack::$text_domain); ?>: <?php echo $parcel
                    ->getDimensions()->getWidth(); ?><?php echo $parcel
                    ->getDimensions()->getUnit(); ?>
                <br>
                <?php _e('Height',
                    EasyPack::$text_domain); ?>: <?php echo $parcel
                    ->getDimensions()->getHeight(); ?><?php echo $parcel
                    ->getDimensions()->getUnit(); ?>
                <br>
                <?php _e('Non standard',
                    EasyPack::$text_domain); ?>: <?php echo $parcel
                    ->is_non_standard() === true
                    ? __('yes',
                        EasyPack::$text_domain)
                    : __('no',
                        EasyPack::$text_domain); ?>
                <br>
                <?php _e('Weight',
                    EasyPack::$text_domain); ?>: <?php echo $parcel
                    ->getWeight()->getAmount(); ?><?php echo $parcel
                    ->getWeight()->getUnit(); ?>
            <?php endif; ?>
        </li>


        <?php $first_parcel = false; ?>
    <?php endforeach; ?>
</ol>
<?php //if ($status == 'new') : ?>
<?php //<button class="button easypack_add_parcel"><?php _e('Add parcel', EasyPack::$text_domain); ?><?php //</button>?>
<?php //endif; ?>
</p>


<?php include('services/html-service-insurance.php'); ?>
<?php include('html-field-reference.php'); ?>


<?php
$custom_attributes = ['style' => 'width:100%;'];
if ($disabled || $send_method_disabled) {
    $custom_attributes['disabled'] = 'disabled';
}
$params = [
    'type' => 'select',
    'options' => $send_methods,
    'class' => ['wc-enhanced-select'],
    'custom_attributes' => $custom_attributes,
    'label' => __('Send method', EasyPack::$text_domain),
];

woocommerce_form_field('easypack_send_method', $params, $send_method);
?>

<p>
    <?php if ($status == 'new') : ?>
        <button id="easypack_send_parcels"
                class="button button-primary"><?php _e('Send parcel',
                EasyPack::$text_domain); ?></button>
    <?php endif; ?>

    <?php if ($shipment instanceof ShipX_Shipment_Model
        && $shipment_service->is_shipment_cancellable($shipment)
    ) {
        $disabled_class = '';
    } else {
        $disabled_class = ' easypack-disabled';
    } ?>

    <button id="easypack_cancel_parcels"
            class="button<?php echo $disabled_class ?>"><?php _e('Cancel parcels',
            EasyPack::$text_domain); ?>
    </button>

    <?php if ( $shipment instanceof ShipX_Shipment_Model
        && !empty($shipment->getInternalData()->getTrackingNumber())) : ?>
        <input id="get_stickers" type="submit" class="button button-primary"
               value="<?php _e('Get sticker(s)', EasyPack::$text_domain); ?>">
        <input type="hidden" name="easypack_get_stickers_request"
               id="easypack_get_stickers_request">
        <input type="hidden" name="easypack_parcel"
               value="<?php echo $shipment->getInternalData()->getOrderId() ?>">
    <?php endif; ?>

    <span id="easypack_spinner" class="spinner"></span>
</p>

<p id="easypack_error"></p>

<a href="#" download id="easypack_download" target="_blank" hidden></a>

<script type="text/javascript">

    jQuery('#get_stickers').click(function () {
        jQuery('#easypack_get_stickers_request').val('1');
        jQuery('#post').attr('target', '_blank');
        jQuery('#post').submit();
        jQuery('#post').attr('target', '_self');
        jQuery('#easypack_get_stickers_request').val('0');

        return false;
    });


    if (jQuery().select2) {
        jQuery("#parcel_machine_id").select2();
    }


    jQuery('#easypack_send_parcels').click(function (e) {
        jQuery('#easypack_error').html('');
        jQuery(this).attr('disabled', true);
        jQuery("#easypack_spinner").addClass("is-active");
        var parcels = [];
        jQuery('select.easypack_parcel').each(function (i) {
            parcels[i] = jQuery(this).val();
        })

        var insurance_amounts = [];
        jQuery('input.insurance_amount').each(function (i) {
            insurance_amounts[i] = jQuery(this).val();
        })


        var data = {
            action: 'easypack',
            easypack_action: '<?php echo $wp_ajax_action_create?>',
            security: easypack_nonce,
            order_id: <?php echo $order_id; ?>,
            parcel_machine_id: jQuery('#parcel_machine_id').val(),
            parcel_length: jQuery('#parcel_length').val(),
            parcel_width: jQuery('#parcel_width').val(),
            parcel_height: jQuery('#parcel_height').val(),
            parcel_weight: jQuery('#parcel_weight').val(),
            parcel_non_standard: jQuery('#parcel_non_standard').val(),
            //parcels: parcels,
            send_method: jQuery('#easypack_send_method').val(),
            insurance_amounts: insurance_amounts,
            reference_number: jQuery('#reference_number').val()
        };
        jQuery.post(ajaxurl, data, function (response) {
            //console.log(response);
            if (response != 0) {
                response = JSON.parse(response);
                //console.log(response);
                console.log(response.status);
                if (response.status == 'ok') {
                    jQuery("#easypack_parcel_machines .inside").html(response.content);

                    return false;
                }
                else {
                    //alert(response.message);
                    jQuery('#easypack_error').html(response.message);
                }
            }
            else {
                //alert('Bad response.');
                jQuery('#easypack_error').html('Invalid response.');
            }
            jQuery("#easypack_spinner").removeClass("is-active");
            jQuery('#easypack_send_parcels').attr('disabled', false);
        });
        return false;

    });


    jQuery('#easypack_calculate_shipment_cost').click(function (e) {
        jQuery('#easypack_calculate_shipment_cost').attr('disabled', true)
        jQuery('#easypack_error').html('');
        jQuery(this).attr('disabled', true);
        jQuery("#easypack_spinner").addClass("is-active");
        var parcels = [];
        jQuery('select.easypack_parcel').each(function (i) {
            parcels[i] = jQuery(this).val();
        })

        var insurance_amounts = [];
        jQuery('input.insurance_amount').each(function (i) {
            insurance_amounts[i] = jQuery(this).val();
        })

        var data = {
            action: 'easypack',
            easypack_action: 'easypack_calculate_shipment_cost',
            security: easypack_nonce,
            order_id: <?php echo $order_id; ?>,
            parcel_length: jQuery('#parcel_length').val(),
            parcel_width: jQuery('#parcel_width').val(),
            parcel_height: jQuery('#parcel_height').val(),
            parcel_weight: jQuery('#parcel_weight').val(),
            parcel_machine_id: jQuery('#parcel_machine_id').val(),
            parcel_non_standard: jQuery('#parcel_non_standard').val(),
            parcels: parcels,
            send_method: jQuery('#easypack_send_method').val(),
            insurance_amounts: insurance_amounts,
            reference_number: jQuery('#reference_number').val()
        };
        jQuery.post(ajaxurl, data, function (response) {
            jQuery('#easypack_calculate_shipment_cost').attr('disabled', false);
            //console.log(response);
            if (response != 0) {
                response = JSON.parse(response);
                //console.log(response);
                if (response.status == 'ok') {
                    if (null === response.cost.error) {
                        jQuery('.shipment_costs_wrapper').removeClass('hidden')
                        jQuery('#calculated_charge_amount').html(response.cost.calculated_charge_amount);
                        jQuery('#calculated_charge_amount_nc').html(response.cost.calculated_charge_amount_non_commission);
                        jQuery('#cod_charge_amount').html(response.cost.cod_charge_amount);
                        jQuery('#fuel_charge_amount').html(response.cost.fuel_charge_amount);
                        jQuery('#insurance_charge_amount').html(response.cost.insurance_charge_amount);
                        jQuery('#notification_charge_amount').html(response.cost.notification_charge_amount);

                    } else {
                        jQuery('.shipment_costs_wrapper').addClass('hidden')
                        jQuery('#easypack_error').html(response.cost.error_message);
                    }

                    jQuery("#easypack_spinner").removeClass("is-active");


                    console.log(response.cost);
                    return false;
                }
                else {
                    jQuery('#easypack_error').html(response.message);
                }
            }
            else {
                //alert('Bad response.');
                jQuery('#easypack_error').html('Invalid response.');
            }
            jQuery("#easypack_spinner").removeClass("is-active");
            jQuery('#easypack_send_parcels').attr('disabled', false);
        });
        return false;

    });


    jQuery('#easypack_cancel_parcels').click(function () {
        jQuery('#easypack_error').html('');
        jQuery(this).attr('disabled', true);
        jQuery("#easypack_spinner").addClass("is-active");
        var data = {
            action: 'easypack',
            easypack_action: 'parcel_machines_cancel_package',
            security: easypack_nonce,
            order_id: <?php echo $order_id; ?>,
        };
        jQuery.post(ajaxurl, data, function (response) {
            console.log(response);
            if (response != 0) {
                response = JSON.parse(response);
                console.log(response);
                if (response.status == 'ok') {
                    jQuery("#easypack_parcel_machines .inside").html(response.content);
                    return false;
                }
                else {
                    //alert(response.message);
                    jQuery('#easypack_error').html(response.message);
                }
            }
            else {
                //alert('Bad response.');
                jQuery('#easypack_error').html('Invalid response.');
            }
            jQuery("#easypack_spinner").removeClass("is-active");
            jQuery('#easypack_cancel_parcels').attr('disabled', false);
        });
        return false;
    });


    jQuery('#easypack_get_stickers_1').click(function (e) {
        e.preventDefault();
        jQuery('#easypack_error').html('');
        jQuery(this).attr('disabled', true);
        jQuery("#easypack_spinner").addClass("is-active");
        var data = {
            action: 'easypack',
            easypack_action: 'parcel_machines_get_stickers',
            security: easypack_nonce,
            order_id: <?php echo $order_id; ?>,
        };
        jQuery.post(ajaxurl, data, function (response) {
            //console.log(response);
            if (response !== 0) {
                response = JSON.parse(response);
                //console.log(response);
                if (response.status === 'success') {
                    var url = response.url;
                    var win = window.location.replace(url);
                    win.focus();
                    //jQuery("#easypack_download").attr( "href", url );
                    //jQuery("#easypack_download").trigger('click');

                    jQuery("#easypack_spinner").removeClass("is-active");
                    jQuery('#easypack_get_stickers').attr('disabled', false);
                    return false;
                }
                else {
                    jQuery('#easypack_error').html(response.message);
                }
            }
            else {
                jQuery('#easypack_error').html('Invalid response.');
            }
            jQuery("#easypack_spinner").removeClass("is-active");
            jQuery('#easypack_get_stickers').attr('disabled', false);
        });
        return false;
    });
</script>
